==> rong-ui-react-0.0.1.tgz: package/es/rc-checkbox/rc-checkbox.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } Object.defineProperty(subClass, "prototype", { value: Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }), writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import './style/rc-checkbox.less';
var prefixCls = 'rc-checkbox';

var RcCheckbox = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(RcCheckbox, _React$PureComponent);

  var _super = _createSuper(RcCheckbox);

  function RcCheckbox(props) {
    var _this;

    _classCallCheck(this, RcCheckbox);

    _this = _super.call(this, props);

    _defineProperty(_assertThisInitialized(_this), "handleChange", function (e) {
      var _this$props = _this.props,
          disabled = _this$props.disabled,
          onChange = _this$props.onChange;
      if (disabled) return;

      if (!('checked' in _this.props)) {
        _this.setState({
          checked: e.target.checked
        });
      }

      onChange && onChange({
        target: _objectSpread(_objectSpread({}, _this.props), {}, {
          checked: e.target.checked
        }),
        stopPropagation: function stopPropagation() {
          e.stopPropagation();
        },
        preventDefault: function preventDefault() {
          e.preventDefault();
        },
        nativeEvent: e.nativeEvent,
        component: _assertThisInitialized(_this)
      });
    });

    _defineProperty(_assertThisInitialized(_this), "saveInput", function (node) {
      _this.input = node;
    });

    var checked = 'checked' in props ? props.checked : props.defaultChecked;
    _this.state = {
      checked: checked
    };
    return _this;
  }

  _createClass(RcCheckbox, [{
    key: "wrapCls",
    get: function get() {
      var _ref;

      var _this$props2 = this.props,
          className = _this$props2.className,
          disabled = _this$props2.disabled,
          type = _this$props2.type;
      var checked = this.state.checked;
      return classNames([prefixCls, className, "".concat(prefixCls, "--").concat(type), (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "--").concat(type, "-checked"), checked), _defineProperty(_ref, "".concat(prefixCls, "--").concat(type, "-disabled"), disabled), _ref)]);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.props.onMounted && this.props.onMounted(this);
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this.props.onUpdated && this.props.onUpdated(this);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          style = _this$props3.style,
          name = _this$props3.name,
          id = _this$props3.id,
          type = _this$props3.type,
          readOnly = _this$props3.readOnly,
          disabled = _this$props3.disabled,
          value = _this$props3.value;
      var checked = this.state.checked;
      console.log('rc-checkbox mounted or updated');
      return /*#__PURE__*/React.createElement("span", {
        className: this.wrapCls,
        style: style
      }, /*#__PURE__*/React.createElement("input", {
        name: name,
        id: id,
        type: type,
        value: value,
        readOnly: readOnly,
        disabled: disabled,
        checked: checked,
        className: "".concat(prefixCls, "-input"),
        onChange: this.handleChange,
        ref: this.saveInput
      }), /*#__PURE__*/React.createElement("span", {
        className: "".concat(prefixCls, "-inner")
      }));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if ('checked' in nextProps) {
        return {
          checked: nextProps.checked
        };
      }

      return null;
    }
  }]);

  return RcCheckbox;
}(React.PureComponent);

setDefaultProps(RcCheckbox, {
  className: {
    type: PropTypes.string
  },
  style: {
    type: PropTypes.object
  },
  type: {
    type: PropTypes.oneOf(['checkbox', 'radio']),
    default: 'checkbox'
  },
  defaultChecked: {
    type: PropTypes.bool,
    default: false
  },
  disabled: {
    type: PropTypes.bool,
    default: false
  },
  readOnly: {
    type: PropTypes.bool,
    default: false
  },
  onChange: {
    type: PropTypes.func
  },
  onMounted: {
    type: PropTypes.func
  },
  onUpdated: {
    type: PropTypes.func
  }
});
export default RcCheckbox;

==> rong-ui-react-0.0.5.tgz: package/es/rc-checkbox/rc-checkbox.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import "./style/rc-checkbox.css";
var prefixCls = 'rc-checkbox';

var RcCheckbox = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(RcCheckbox, _React$PureComponent);

  var _super = _createSuper(RcCheckbox);

  function RcCheckbox(props) {
    var _this;

    _classCallCheck(this, RcCheckbox);

    _this = _super.call(this, props);

    _this.handleChange = function (e) {
      var _this$props = _this.props,
          disabled = _this$props.disabled,
          onChange = _this$props.onChange;
      if (disabled) return;

      if (!('checked' in _this.props)) {
        _this.setState({
          checked: e.target.checked
        });
      }

      onChange && onChange({
        target: _objectSpread(_objectSpread({}, _this.props), {}, {
          checked: e.target.checked
        }),
        stopPropagation: function stopPropagation() {
          e.stopPropagation();
        },
        preventDefault: function preventDefault() {
          e.preventDefault();
        },
        nativeEvent: e.nativeEvent,
        component: _assertThisInitialized(_this)
      });
    };

    _this.saveInput = function (node) {
      _this.input = node;
    };

    var checked = 'checked' in props ? props.checked : props.defaultChecked;
    _this.state = {
      checked: checked
    };
    return _this;
  }

  _createClass(RcCheckbox, [{
    key: "wrapCls",
    get: function get() {
      var _ref;

      var _this$props2 = this.props,
          className = _this$props2.className,
          disabled = _this$props2.disabled,
          type = _this$props2.type;
      var checked = this.state.checked;
      return classNames([prefixCls, className, "".concat(prefixCls, "--").concat(type), (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "--").concat(type, "-checked"), checked), _defineProperty(_ref, "".concat(prefixCls, "--").concat(type, "-disabled"), disabled), _ref)]);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.props.onMounted && this.props.onMounted(this);
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      this.props.onUpdated && this.props.onUpdated(this);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          style = _this$props3.style,
          name = _this$props3.name,
          id = _this$props3.id,
          type = _this$props3.type,
          readOnly = _this$props3.readOnly,
          disabled = _this$props3.disabled,
          value = _this$props3.value;
      var checked = this.state.checked;
      console.log('rc-checkbox mounted or updated');
      return /*#__PURE__*/React.createElement("span", {
        className: this.wrapCls,
        style: style
      }, /*#__PURE__*/React.createElement("input", {
        name: name,
        id: id,
        type: type,
        value: value,
        readOnly: readOnly,
        disabled: disabled,
        checked: checked,
        className: "".concat(prefixCls, "-input"),
        onChange: this.handleChange,
        ref: this.saveInput
      }), /*#__PURE__*/React.createElement("span", {
        className: "".concat(prefixCls, "-inner")
      }));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, prevState) {
      if ('checked' in nextProps) {
        return {
          checked: nextProps.checked
        };
      }

      return null;
    }
  }]);

  return RcCheckbox;
}(React.PureComponent);

setDefaultProps(RcCheckbox, {
  className: {
    type: PropTypes.string
  },
  style: {
    type: PropTypes.object
  },
  type: {
    type: PropTypes.oneOf(['checkbox', 'radio']),
    default: 'checkbox'
  },
  defaultChecked: {
    type: PropTypes.bool,
    default: false
  },
  disabled: {
    type: PropTypes.bool,
    default: false
  },
  readOnly: {
    type: PropTypes.bool,
    default: false
  },
  onChange: {
    type: PropTypes.func
  },
  onMounted: {
    type: PropTypes.func
  },
  onUpdated: {
    type: PropTypes.func
  }
});
export default RcCheckbox;
